The module provides a class for finite discrete distributions which are utilized for discrete-time analysis. For example, discrete-time GI/GI/1 systems can be analyzed with functions of the module.

    from discreteTimeAnalysis import *
    A = DU(0,10) # interarrival time
    B = DU(2,7) # service time

    # GI/GI/1: Power method 
    Wn1 = DET(0) # empty system
    Wn = DET(1)  # just for initialization

    # power method
    while Wn != Wn1: # comparison based on means of the distributions
        Wn = Wn1
        Wn1 = max( Wn+C ,0)

    Wn1.plotCDF()


This module is part of the following book. The book is to be cited whenever the script is used (copyright CC BY-SA 4.0):
- *Tran-Gia, P. & Hossfeld, T. (2021). Performance Modeling and Analysis of Communication Networks - A Lecture Note. Würzburg University Press. https://doi.org/10.25972/WUP-978-3-95826-153-2*

# Performance Modeling and Analysis of Communication Networks

The text book "Performance Modeling and Analysis of Communication Networks" by Tran-Gia, P. & Hossfeld, T. is published in 2021 as open access book by the Würzburg University Press. The book focuses on the fundamental models of queueing theory as well as advanced models for recent communication systems and networks. It gives an introduction in common methods of performance modeling and analysis of communication systems. These methods form the basis of traffic engineering, teletraffic theory, and system analytical dimensioning tools. The fundamentals of probability theory, stochastic processes, Markov processes, and embedded Markov chains are presented. Basic queueing models are described with applications in communication networks. Advanced methods are presented that have been frequently used in practice, especially discrete-time analysis algorithms, or which go beyond classical performance like quality of experience or energy efficiency. Recent examples of modern communication networks include Software Defined Networking or the Internet of Things. Throughout the book, illustrative examples are used to provide practical experience in performance modeling and analysis.

An implementation of the models in the book is available as interactive notebooks online. The scripts will help to better understand the impact of parameters on performance characteristics, will avoid common pitfalls in the implementation, and provide means for numerical robust and efficient implementations for researchers in the domain.

Website of the book:
<https://modeling.systems>

##  Copyright Notice
The scripts are published under the license: [CC BY-SA 4.0](https://creativecommons.org/licenses/by-sa/4.0/).
Permission is hereby granted, without written agreement and without license or royalty fees, to use, copy, modify, and distribute this tool and its documentation for any purpose, provided that the copyright notice in its entirety appear in all copies of this tool, and the original source of this tool is acknowledged in any publication that reports research using this tool. If you remix, transform, or build upon the material, you must distribute your contributions under the same license as the original.

The book is to be cited in the bibliography whenever the scripts are used. 
- *Tran-Gia, P. & Hossfeld, T. (2021). Performance Modeling and Analysis of Communication Networks - A Lecture Note. Würzburg University Press. https://doi.org/10.25972/WUP-978-3-95826-153-2*